package
Version:
v0.0.0-...-d79ae21
Opens a new window with list of versions in this module.
Published: May 6, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Choice[T any](S []T) T
func RemoveByIndex[S any](slice []S, i int) ([]S, error)
const (
Windows OSType = iota
Linux
MacOS
OpenBSD
FreeBSD
UnknownOS
)
func GetRuntimeOS() (ostype OSType)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.